@@ -7,6 +7,11 @@ from __future__ import (
 import posixpath
 import zipfile
 from collections import defaultdict
+try:
+    from cString import StringIO
+    BytesIO = StringIO
+except ImportError:
+    from io import BytesIO
 from xml.etree import cElementTree
 
 from pydocx.exceptions import MalformedDocxException
@@ -151,7 +156,7 @@ class ZipPackagePart(PackageRelationshipManager):
     @staticmethod
     def get_relationship_part_uri(part_uri):
         container, filename = posixpath.split(part_uri)
-        filename_rels = '%s.rels' % filename
+        filename_rels = '{file}.rels'.format(file=filename)
         return posixpath.join(container, '_rels', filename_rels)
 
     def get_part_container(self):
@@ -190,7 +195,8 @@ class ZipPackage(PackageRelationshipManager):
         try:
             uris = f.namelist()
             for uri in uris:
-                self.streams[self.uri + uri] = f.open(uri, 'r')
+                data = f.read(uri)
+                self.streams[self.uri + uri] = BytesIO(data)
         finally:
             f.close()
         for uri in self.streams:
@@ -213,8 +219,8 @@ class ZipPackage(PackageRelationshipManager):
         self._ensure_parts_are_loaded()
         if self.part_exists(uri):
             raise RuntimeError(
-                'A part with the specified URI "%s" already exists' % (
-                    uri,
+                'A part with the specified URI "{uri}" already exists'.format(
+                    uri=uri,
                 )
             )
         part = ZipPackagePart(package=self, uri=uri)
