@@ -116,6 +116,13 @@ class ConvertDocxToHtmlTestCase(TestCase):
         assert actual_html is not None
         assert '\u0391\u03b1' in actual_html
 
+    def test_result_from_file_pointer_matches_result_from_path(self):
+        path = self.get_path_to_fixture('simple.docx')
+        path_html = self.convert_docx_to_html(path)
+        file_html = self.convert_docx_to_html(open(path, 'rb'))
+        assert file_html
+        self.assertEqual(path_html, file_html)
+
 ConvertDocxToHtmlTestCase.generate()
 
 
@@ -153,22 +160,6 @@ def test_has_image():
     ''' % image_data)
 
 
-def test_local_dpi():
-    # The image in this file does not have a set height or width, show that the
-    # html will generate without it.
-    file_path = os.path.join(
-        os.path.abspath(os.path.dirname(__file__)),
-        '..',
-        'fixtures',
-        'localDpi.docx',
-    )
-    actual_html = convert(file_path)
-    image_data = get_image_data(file_path, 'image1.jpeg')
-    assert_html_equal(actual_html, BASE_HTML % '''
-        <p><img src="data:image/jpeg;base64,%s" /></p>
-    ''' % image_data)
-
-
 @raises(MalformedDocxException)
 def test_malformed_docx_exception():
     with NamedTemporaryFile(suffix='.docx') as f:
